
# q-expansion of newform 4000.2.f.d, downloaded from the LMFDB on 16 November 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 4000
weight = 2
poly_data = [1024, -1536, 1536, -640, -192, 640, -448, 192, 64, -120, 116, -60, 16, 24, -28, 20, -3, -5, 6, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[10752, -7168, 5120, 1856, -3200, 2944, -384, -224, 944, -404, 388, -16, -88, 200, -90, 23, 43, -32, 11, 1], 3072], [[-2048, 3328, -1408, -832, -64, -768, 480, -128, -184, 212, -236, -16, -16, -44, 20, -19, -5, 6, -11, 1], 1536], [[7168, -8960, 2432, 320, -3904, 1920, -672, -512, 536, -484, 124, -112, -160, 124, -100, -1, 25, -30, 7, -5], 1536], [[-9728, 14336, -15104, 3904, 3456, -6720, 3648, -832, -1232, 1356, -860, 384, -24, -256, 278, -145, 3, 80, -61, 17], 3072], [[8704, -7168, 14080, -3392, -768, 5184, -3840, 1568, 880, -684, 988, -288, 24, 152, -238, 185, -3, -40, 53, -25], 3072], [[2560, -512, 3072, -2240, 0, 704, -1152, 640, 128, -276, 212, -192, -8, -24, -62, 47, -17, -12, 11, -11], 1024], [[32256, -34304, 15872, -1344, -12288, 10048, -3136, 0, 1920, -2268, 1180, -672, -360, 600, -394, 101, 69, -132, 41, -25], 3072], [[1024, 4992, -4608, 3072, 640, -1776, 1776, -144, -60, 424, -260, 220, -20, -30, 119, -52, 11, 25, -18, 9], 768], [[3072, -8448, 6656, -6080, -2176, 2656, -3296, 608, 184, -964, 316, -488, -32, 52, -188, 95, -31, -46, 23, -21], 1536], [[10752, -15616, 11136, -3008, -4864, 5760, -2944, 368, 952, -1156, 732, -416, -32, 256, -268, 111, 17, -70, 39, -17], 1536], [[-19968, 19712, -9216, 448, 8384, -6240, 2528, 272, -1208, 1628, -756, 424, 280, -368, 272, -57, -43, 86, -33, 19], 1536], [[-26112, 37888, -19456, 7488, 13824, -10496, 6464, 192, -1584, 3084, -1148, 1200, 360, -528, 590, -193, -21, 168, -61, 41], 3072], [[-8448, 12800, -7360, 704, 4960, -4304, 1920, 256, -760, 940, -452, 260, 104, -220, 192, -49, -35, 58, -25, 7], 768], [[-4608, 11776, -11520, 3776, 2816, -5248, 3328, -480, -576, 996, -676, 432, -8, -176, 262, -107, 5, 60, -39, 15], 1024], [[-24064, 47616, -33792, 14016, 15872, -16704, 11136, -1152, -2400, 3668, -2164, 1568, 200, -696, 886, -335, -23, 212, -123, 51], 3072], [[-13824, 23552, -20608, 4928, 6976, -9440, 5376, -608, -1504, 1852, -1340, 584, 8, -400, 450, -181, -29, 100, -73, 25], 1536], [[13824, 31232, -26624, 25408, 3200, -10560, 13824, -2272, 448, 3164, -1500, 1664, -280, 32, 762, -405, 187, 148, -121, 65], 3072], [[-21504, 35328, -27904, 10432, 11264, -12224, 8704, -1216, -1760, 2900, -1652, 1216, 136, -488, 646, -271, -7, 164, -91, 51], 1536], [[-77312, 100864, -90112, 15296, 32768, -42816, 21504, -2624, -8320, 7268, -5924, 2528, 296, -1880, 1814, -811, -203, 444, -311, 103], 3072]]

hecke_ring_character_values = [[2751, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2501, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1377, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, -1, 0, 1, 0, 0, 1, 0, -1, 0], [0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, -1, 1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1], [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1], [0, 0, -1, -1, -1, 1, 0, 0, -1, 0, 0, 0, 0, 0, 1, -1, 0, 1, 0, -1], [-1, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, -1, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, -1, 0, 0, 0], [1, 1, 0, 0, 0, 0, 0, 1, 0, -3, -1, 1, -1, 0, 0, 0, 0, 0, -1, 0], [-3, 0, 0, 0, 0, 0, 0, 1, 0, -1, -1, 0, -1, -1, 0, 0, 1, 0, -1, 0], [0, 0, 1, 1, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0, -1, 2, 0, -1, 0, 0], [-1, -2, 0, 0, 0, 0, 0, -1, 0, 2, 3, -1, 0, 0, 0, 0, 0, 0, 1, 0], [0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1], [0, 0, 0, -2, 0, -2, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0, 3, -1, 0, 0, 1, 0, 1, 0], [-2, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 2, -2, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, -2, 2, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0], [3, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, -1, 0, 0, 0, 0, 1, 0], [3, -1, 0, 0, 0, 0, 0, -2, 0, 1, 1, 0, 1, -1, 0, 0, 0, 0, -1, 0], [-1, 3, 0, 0, 0, 0, 0, 1, 0, 1, 1, -1, 1, -1, 0, 0, 1, 0, -1, 0], [0, 0, -1, 0, -1, 1, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -2], [0, 0, 1, -2, -2, 2, -1, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 1, 0, 0], [0, 0, -2, 0, 1, 0, -1, 0, -1, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 1], [-1, 5, 0, 0, 0, 0, 0, -2, 0, -2, 1, -2, -1, 1, 0, 0, 2, 0, -1, 0], [0, 0, 0, 2, 0, 0, -1, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0, -1, 0, 0], [0, 0, 1, 0, -3, 1, 0, 0, -2, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 2], [0, 0, 1, -3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, -2], [0, 0, 0, 0, -1, -1, 0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 0, -1, 0, -1], [0, 0, 0, 0, 3, -1, 2, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 1, -4, -1, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -1], [0, 0, -3, -1, 0, -2, -1, 0, 1, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 1], [7, 0, 0, 0, 0, 0, 0, 1, 0, -2, -3, 4, -1, -1, 0, 0, -1, 0, -1, 0], [3, -1, 0, 0, 0, 0, 0, -2, 0, -1, 0, -2, 1, 1, 0, 0, -1, 0, 0, 0], [8, 2, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 2, -2, 0, 0, 0, 0, 0, 0], [0, 0, -1, -1, 1, 0, 2, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, -2], [4, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 2, -2, -1, 0, 0, -1, 0, 2, 0], [0, 0, 0, -2, -2, -1, 0, 0, -2, 0, 0, 0, 0, 0, 2, -2, 0, 2, 0, -2], [0, 0, 2, -1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, -1, 1, 0, -2, 0, 1], [6, 2, 0, 0, 0, 0, 0, 0, 0, -4, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0], [0, 0, -1, 0, 1, -1, 1, 0, 3, 0, 0, 0, 0, 0, -2, 0, 0, 1, 0, -2], [3, 3, 0, 0, 0, 0, 0, -3, 0, 2, -1, 1, -2, 0, 0, 0, 0, 0, 1, 0], [3, 0, 0, 0, 0, 0, 0, -5, 0, -3, 0, -2, -3, 3, 0, 0, 1, 0, -3, 0], [0, 0, 1, -1, -4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 0, 2, 4, -1, 3, 0, 1, 0, 0, 0, 0, 0, -2, 2, 0, 2, 0, 0], [0, -6, 0, 0, 0, 0, 0, -2, 0, -1, 1, 2, 0, 2, 0, 0, 2, 0, -2, 0], [0, 0, -3, 3, 1, -3, 1, 0, 2, 0, 0, 0, 0, 0, -3, -1, 0, 2, 0, -1], [0, 0, -3, -1, 1, 3, -2, 0, 1, 0, 0, 0, 0, 0, -1, -1, 0, 1, 0, -1], [-4, 1, 0, 0, 0, 0, 0, -3, 0, -3, 6, -2, 0, 2, 0, 0, 1, 0, -2, 0], [4, -2, 0, 0, 0, 0, 0, 2, 0, -1, -8, 4, -1, 1, 0, 0, -3, 0, 0, 0], [0, 0, -5, -1, 1, 2, 1, 0, 4, 0, 0, 0, 0, 0, -1, -4, 0, 3, 0, -2], [0, 0, -3, 1, 3, -1, 0, 0, 3, 0, 0, 0, 0, 0, -1, -1, 0, 1, 0, -1], [0, 0, -1, 1, -1, 1, -1, 0, 4, 0, 0, 0, 0, 0, -3, -2, 0, 1, 0, -2], [0, 0, -2, 3, -4, 2, -1, 0, 0, 0, 0, 0, 0, 0, -3, -3, 0, 0, 0, 3], [-3, 4, 0, 0, 0, 0, 0, 1, 0, 6, 4, 0, 3, -1, 0, 0, 1, 0, -1, 0], [3, -5, 0, 0, 0, 0, 0, 2, 0, -2, 0, 1, 0, 0, 0, 0, 2, 0, 1, 0], [-2, 3, 0, 0, 0, 0, 0, -1, 0, -3, 7, -1, 1, -2, 0, 0, 2, 0, -1, 0], [-8, 5, 0, 0, 0, 0, 0, -3, 0, -2, 3, 0, 0, 0, 0, 0, 3, 0, 2, 0], [4, 2, 0, 0, 0, 0, 0, 0, 0, -1, -4, 2, 3, -1, 0, 0, 1, 0, 0, 0], [0, -2, 0, 0, 0, 0, 0, 0, 0, -3, -6, 2, -2, -2, 0, 0, -2, 0, 0, 0], [-2, 3, 0, 0, 0, 0, 0, -3, 0, 7, 8, -4, 6, 2, 0, 0, 3, 0, 0, 0], [0, 0, -2, -4, 0, -4, 0, 0, -2, 0, 0, 0, 0, 0, 2, -4, 0, 0, 0, -2], [7, 1, 0, 0, 0, 0, 0, -3, 0, 1, 1, 1, 1, -1, 0, 0, 3, 0, -1, 0], [0, 0, 3, -1, 0, 2, -2, 0, -4, 0, 0, 0, 0, 0, 1, -2, 0, -2, 0, 1], [0, 0, 3, 2, 1, 1, 2, 0, 4, 0, 0, 0, 0, 0, -2, 2, 0, 2, 0, 0], [3, 4, 0, 0, 0, 0, 0, -3, 0, 1, -1, -2, -1, 3, 0, 0, -1, 0, 1, 0], [0, 0, -1, -3, 2, 4, 3, 0, -1, 0, 0, 0, 0, 0, 3, -1, 0, 2, 0, -1], [0, 0, 0, 1, 6, 4, 2, 0, 3, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, -1], [-2, -3, 0, 0, 0, 0, 0, 7, 0, -3, -7, 2, 2, -2, 0, 0, -1, 0, 0, 0], [0, 0, -3, -1, 0, 0, -1, 0, 1, 0, 0, 0, 0, 0, -2, -4, 0, 0, 0, 1], [1, -5, 0, 0, 0, 0, 0, 3, 0, -1, -9, 4, -7, 0, 0, 0, -4, 0, 2, 0], [0, 0, -2, 2, 3, 3, 1, 0, 5, 0, 0, 0, 0, 0, -2, 2, 0, 1, 0, -1], [0, 0, -2, 2, -2, -1, 0, 0, -2, 0, 0, 0, 0, 0, 0, -4, 0, 2, 0, 2], [0, 0, 1, -5, 2, 2, -3, 0, 1, 0, 0, 0, 0, 0, -1, 1, 0, -2, 0, -3], [-4, 6, 0, 0, 0, 0, 0, -1, 0, -8, -1, -2, -4, -1, 0, 0, -1, 0, 2, 0], [5, 1, 0, 0, 0, 0, 0, -2, 0, 0, -2, -1, 0, -1, 0, 0, 3, 0, 3, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 7, 4, 0, 1, 1, 0, 0, -3, 0, 2, 0], [0, 0, 2, -4, 1, -2, 1, 0, 2, 0, 0, 0, 0, 0, 2, 2, 0, -3, 0, 1], [0, 0, 1, 4, 1, 1, -3, 0, 1, 0, 0, 0, 0, 0, -4, 2, 0, -1, 0, 2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 4, 0, 0, 0, -4, 0, 0, 0], [0, 0, -2, 2, 1, -3, -1, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 1, 0, 2], [3, -4, 0, 0, 0, 0, 0, 1, 0, 5, 3, 0, 3, 3, 0, 0, -1, 0, 3, 0], [-12, 10, 0, 0, 0, 0, 0, -2, 0, -4, 3, -2, 0, 2, 0, 0, 0, 0, -4, 0], [3, 1, 0, 0, 0, 0, 0, 3, 0, -7, -7, 2, -1, -4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, -2, -4, -4, 0, -7, 0, 0, 0, 0, 0, -1, 1, 0, -1, 0, 1], [0, 0, -4, 3, -1, 1, -4, 0, -2, 0, 0, 0, 0, 0, -3, -3, 0, -1, 0, 5], [0, 0, -1, -5, -6, -1, -2, 0, -2, 0, 0, 0, 0, 0, 2, -2, 0, 0, 0, -1], [-1, -6, 0, 0, 0, 0, 0, -1, 0, -5, 0, 2, -1, 3, 0, 0, -1, 0, -1, 0], [6, -7, 0, 0, 0, 0, 0, -3, 0, 3, -1, 0, 4, 2, 0, 0, 1, 0, -2, 0], [0, 0, 2, -4, 3, 0, 2, 0, -2, 0, 0, 0, 0, 0, 2, 2, 0, -1, 0, -3], [0, 0, 0, 6, 0, 0, 1, 0, -1, 0, 0, 0, 0, 0, -4, 0, 0, 2, 0, 2], [0, 0, -1, -1, 0, -1, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, 1, 5, -1, 2, 3, 0, 3, 0, 0, 0, 0, 0, 2, 2, 0, 1, 0, 2], [0, 0, 4, -3, -6, -2, -2, 0, -1, 0, 0, 0, 0, 0, -1, 3, 0, -1, 0, -1], [-3, 4, 0, 0, 0, 0, 0, -5, 0, -2, 7, -3, -2, 5, 0, 0, 1, 0, -1, 0], [-11, 1, 0, 0, 0, 0, 0, -2, 0, 7, 5, 0, -1, -3, 0, 0, -4, 0, 5, 0], [0, 0, -2, 3, 5, 3, 3, 0, 7, 0, 0, 0, 0, 0, -3, 1, 0, 0, 0, -3], [-11, 0, 0, 0, 0, 0, 0, -1, 0, -4, -7, 0, -3, -1, 0, 0, -5, 0, -1, 0], [-12, 9, 0, 0, 0, 0, 0, 1, 0, -5, -5, -3, 3, -2, 0, 0, 4, 0, -1, 0], [10, -10, 0, 0, 0, 0, 0, 2, 0, -2, 2, -4, 4, 0, 0, 0, 4, 0, -4, 0], [-4, -3, 0, 0, 0, 0, 0, 3, 0, -1, 3, 3, -5, 2, 0, 0, -2, 0, -3, 0], [0, 0, 3, 1, 4, 2, 1, 0, 7, 0, 0, 0, 0, 0, 1, 4, 0, -2, 0, -3], [0, 0, 7, -2, 0, -2, 6, 0, 1, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, -4], [4, 4, 0, 0, 0, 0, 0, 6, 0, 4, -6, 4, 2, 0, 0, 0, -4, 0, 6, 0], [0, 0, -1, -4, -3, -3, 0, 0, 0, 0, 0, 0, 0, 0, 4, -2, 0, 0, 0, 2], [8, -10, 0, 0, 0, 0, 0, 0, 0, 3, 8, 4, 2, 0, 0, 0, -4, 0, 4, 0], [0, -1, 0, 0, 0, 0, 0, 2, 0, -2, 0, -3, -4, 3, 0, 0, -1, 0, 1, 0], [0, 0, -3, 5, 5, -4, 0, 0, 3, 0, 0, 0, 0, 0, -3, 2, 0, 1, 0, -4], [3, 4, 0, 0, 0, 0, 0, 0, 0, -3, 2, -4, 7, -2, 0, 0, 2, 0, -4, 0], [0, 0, -1, 0, 2, 2, 1, 0, 6, 0, 0, 0, 0, 0, -4, 0, 0, 1, 0, -4], [0, 0, 0, 0, 6, -4, 3, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0], [3, -5, 0, 0, 0, 0, 0, 2, 0, 1, -1, 2, -7, 1, 0, 0, -2, 0, 3, 0], [-3, 6, 0, 0, 0, 0, 0, -3, 0, -2, -7, -3, -2, 0, 0, 0, 0, 0, -3, 0], [15, -12, 0, 0, 0, 0, 0, 1, 0, 2, 6, 2, 3, -3, 0, 0, 7, 0, 1, 0], [0, 0, -5, 5, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, -4, 2, 0, 3, 0, -2], [-4, 0, 0, 0, 0, 0, 0, 1, 0, 2, -5, -4, -2, 0, 0, 0, 0, 0, 4, 0], [0, 0, -1, -3, 2, 0, 6, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0, 2, 0, -1], [0, 0, 0, 1, 2, 0, 2, 0, -5, 0, 0, 0, 0, 0, 3, -1, 0, 1, 0, 3], [0, 0, -2, 4, 1, -1, -4, 0, -7, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0, 8], [-2, 7, 0, 0, 0, 0, 0, 2, 0, -8, -2, 7, 4, -2, 0, 0, -2, 0, -1, 0], [-17, 15, 0, 0, 0, 0, 0, -4, 0, 5, 4, -2, 3, 5, 0, 0, 2, 0, -3, 0], [0, 0, 1, 3, 4, 1, -1, 0, 1, 0, 0, 0, 0, 0, -1, 4, 0, -2, 0, 1], [0, 0, -3, -1, 2, 8, 2, 0, 0, 0, 0, 0, 0, 0, 5, -1, 0, 1, 0, -1], [0, 0, 8, -1, 1, -3, -2, 0, -6, 0, 0, 0, 0, 0, 5, 1, 0, -3, 0, 3], [-1, -9, 0, 0, 0, 0, 0, 2, 0, -4, 6, 2, 1, -1, 0, 0, 6, 0, -1, 0], [0, 0, 2, -6, 5, 5, -5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1], [1, -13, 0, 0, 0, 0, 0, -8, 0, 0, -2, -2, 0, 2, 0, 0, 2, 0, -2, 0], [0, 0, 2, 2, -1, 3, -2, 0, 1, 0, 0, 0, 0, 0, 1, -2, 0, 3, 0, 1], [0, 0, -4, -2, 3, 1, 0, 0, 4, 0, 0, 0, 0, 0, -1, -2, 0, -1, 0, 1], [-13, 3, 0, 0, 0, 0, 0, 6, 0, -1, -8, 0, -11, 1, 0, 0, -2, 0, -3, 0], [3, -2, 0, 0, 0, 0, 0, -2, 0, 1, 2, -2, -5, 6, 0, 0, 2, 0, 0, 0], [0, 5, 0, 0, 0, 0, 0, -8, 0, -2, 4, -3, 0, 0, 0, 0, 0, 0, -3, 0], [-4, -1, 0, 0, 0, 0, 0, 4, 0, 2, -6, -1, 2, 3, 0, 0, -5, 0, 1, 0], [-4, -5, 0, 0, 0, 0, 0, 2, 0, 9, -4, -3, 1, 4, 0, 0, 0, 0, -1, 0], [-18, -6, 0, 0, 0, 0, 0, -4, 0, 4, 5, 4, 2, -2, 0, 0, 2, 0, 0, 0], [12, -11, 0, 0, 0, 0, 0, -4, 0, -2, 0, 0, 2, 2, 0, 0, -4, 0, 2, 0], [-3, -4, 0, 0, 0, 0, 0, 5, 0, 4, 7, -2, 2, 1, 0, 0, 3, 0, 0, 0], [0, 0, -2, -2, -2, 8, 2, 0, -3, 0, 0, 0, 0, 0, 5, 0, 0, 4, 0, -4], [0, 0, -3, 5, 0, -4, 0, 0, 2, 0, 0, 0, 0, 0, -1, -1, 0, 3, 0, -5], [0, 0, 2, -2, 9, 7, 4, 0, 7, 0, 0, 0, 0, 0, 5, 4, 0, -1, 0, -5], [6, 10, 0, 0, 0, 0, 0, 8, 0, -5, -4, 4, 2, -2, 0, 0, -2, 0, 0, 0], [0, 0, -1, 2, 4, 4, 2, 0, 9, 0, 0, 0, 0, 0, 0, 4, 0, -2, 0, -2], [8, 0, 0, 0, 0, 0, 0, 4, 0, -1, -6, 6, -4, 0, 0, 0, 2, 0, -4, 0], [-9, 2, 0, 0, 0, 0, 0, -7, 0, 2, 7, 0, -8, 8, 0, 0, 0, 0, -4, 0], [0, 0, -6, 3, -3, 1, -1, 0, -9, 0, 0, 0, 0, 0, -1, -7, 0, 2, 0, 3], [0, 0, 7, -3, -4, 6, -4, 0, -4, 0, 0, 0, 0, 0, 4, 0, 0, -4, 0, 5], [0, 0, 1, -1, -1, 0, 4, 0, -1, 0, 0, 0, 0, 0, -1, -4, 0, -1, 0, 0], [-13, -2, 0, 0, 0, 0, 0, 0, 0, 15, 6, 3, 3, 4, 0, 0, 0, 0, 1, 0], [-2, 2, 0, 0, 0, 0, 0, -3, 0, -6, -3, -4, -2, -3, 0, 0, -3, 0, 0, 0], [23, -6, 0, 0, 0, 0, 0, 3, 0, 3, -5, -2, -1, -3, 0, 0, 3, 0, -1, 0], [0, 0, 4, 2, 4, 3, 5, 0, 5, 0, 0, 0, 0, 0, 1, 4, 0, 2, 0, -2], [13, 6, 0, 0, 0, 0, 0, -7, 0, 4, 2, -6, 5, -1, 0, 0, 1, 0, 1, 0], [3, -4, 0, 0, 0, 0, 0, -1, 0, 11, 6, -2, -3, 1, 0, 0, 3, 0, 3, 0], [-8, 11, 0, 0, 0, 0, 0, 1, 0, -4, -3, 2, -2, 4, 0, 0, -1, 0, -4, 0], [8, -6, 0, 0, 0, 0, 0, 6, 0, 3, 2, 6, 3, -5, 0, 0, -1, 0, 4, 0], [0, 0, 0, 2, -3, -3, 0, 0, -3, 0, 0, 0, 0, 0, -2, 2, 0, 2, 0, 0], [0, 0, -1, 3, -1, -1, 1, 0, -2, 0, 0, 0, 0, 0, -1, 3, 0, -2, 0, 1], [2, -12, 0, 0, 0, 0, 0, -6, 0, 6, 5, -2, -2, 0, 0, 0, 2, 0, 4, 0], [0, 0, -3, 1, 4, 0, -2, 0, -4, 0, 0, 0, 0, 0, -3, 1, 0, 5, 0, -1], [0, 0, -4, -8, 2, -1, -3, 0, 2, 0, 0, 0, 0, 0, -1, -2, 0, 0, 0, -4], [0, 0, -13, 1, 2, -3, 0, 0, -7, 0, 0, 0, 0, 0, -3, -2, 0, 6, 0, -1], [0, 0, -1, -6, 0, -4, -4, 0, -5, 0, 0, 0, 0, 0, 2, -6, 0, 0, 0, 2], [0, 0, -8, 0, 2, -7, 0, 0, -1, 0, 0, 0, 0, 0, -4, 2, 0, 0, 0, -2], [7, -2, 0, 0, 0, 0, 0, 1, 0, 1, -5, -4, 5, 3, 0, 0, 3, 0, -1, 0], [-2, 0, 0, 0, 0, 0, 0, -4, 0, 15, 4, -3, 1, 2, 0, 0, -2, 0, 5, 0], [1, -3, 0, 0, 0, 0, 0, -2, 0, 3, 0, -1, -3, -3, 0, 0, -3, 0, 1, 0], [9, -5, 0, 0, 0, 0, 0, -2, 0, -10, 2, -2, 0, 3, 0, 0, 7, 0, 0, 0], [0, 0, 8, -2, -3, -2, -5, 0, 3, 0, 0, 0, 0, 0, -3, 4, 0, -3, 0, -1], [0, 0, 1, 2, 4, -2, 5, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, -2], [7, 6, 0, 0, 0, 0, 0, -3, 0, -13, -5, -6, -7, -1, 0, 0, 5, 0, -5, 0], [0, 0, 8, 5, -2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 1], [4, -7, 0, 0, 0, 0, 0, -1, 0, -9, -1, 6, -6, -2, 0, 0, -7, 0, 4, 0], [3, 3, 0, 0, 0, 0, 0, -1, 0, 4, 5, 4, 10, 2, 0, 0, 2, 0, -4, 0], [0, 0, 6, 4, 2, -6, -1, 0, -1, 0, 0, 0, 0, 0, -2, 4, 0, -2, 0, 6], [0, 0, -3, 2, 1, -7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, -4], [0, 0, -4, -6, -8, 4, -5, 0, 0, 0, 0, 0, 0, 0, 4, -6, 0, 4, 0, -2], [0, 0, 4, -4, 1, 5, -3, 0, 6, 0, 0, 0, 0, 0, 2, 4, 0, -1, 0, -4], [0, 0, 0, -6, 1, 1, 4, 0, -2, 0, 0, 0, 0, 0, 5, 0, 0, 1, 0, 1], [0, 0, -4, 4, -6, 0, 1, 0, -1, 0, 0, 0, 0, 0, 1, -2, 0, -2, 0, 0], [6, -1, 0, 0, 0, 0, 0, 3, 0, -12, -13, 5, -2, 1, 0, 0, 1, 0, 1, 0], [0, 0, -3, 2, 6, -4, 5, 0, 6, 0, 0, 0, 0, 0, -2, 2, 0, 5, 0, -6], [0, 0, -3, 3, 7, -4, -1, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2], [0, 0, -4, 0, -3, 3, 2, 0, 1, 0, 0, 0, 0, 0, -2, 0, 0, 2, 0, 2], [15, -12, 0, 0, 0, 0, 0, 0, 0, -1, -4, 0, 1, 1, 0, 0, 5, 0, -6, 0], [26, -8, 0, 0, 0, 0, 0, 0, 0, 8, -5, 2, 4, -2, 0, 0, -2, 0, 6, 0], [-5, 0, 0, 0, 0, 0, 0, -5, 0, -2, 3, -4, 0, 1, 0, 0, -1, 0, -6, 0], [-23, 8, 0, 0, 0, 0, 0, -5, 0, -14, 4, -4, 1, 3, 0, 0, 3, 0, -1, 0], [0, 0, -2, 1, -5, 7, -2, 0, 0, 0, 0, 0, 0, 0, -1, -5, 0, 9, 0, -1], [-13, 15, 0, 0, 0, 0, 0, -4, 0, -14, 1, 2, -1, -3, 0, 0, 2, 0, -3, 0], [0, 0, 5, 1, -6, 4, -2, 0, -3, 0, 0, 0, 0, 0, 2, -6, 0, 4, 0, 3], [0, 0, -6, 6, -6, 6, 1, 0, 1, 0, 0, 0, 0, 0, -2, -6, 0, 5, 0, 2], [-2, -22, 0, 0, 0, 0, 0, 0, 0, 2, 1, -4, -2, 2, 0, 0, -2, 0, 0, 0], [0, 0, 0, -4, -4, 2, -2, 0, -6, 0, 0, 0, 0, 0, 4, -2, 0, 4, 0, -6], [-2, -8, 0, 0, 0, 0, 0, 4, 0, -3, -4, 1, 1, 1, 0, 0, -5, 0, -1, 0], [-11, 1, 0, 0, 0, 0, 0, 3, 0, 5, 5, -5, 9, 2, 0, 0, -2, 0, -1, 0], [0, 0, -5, 3, -4, -6, -1, 0, -1, 0, 0, 0, 0, 0, -3, -1, 0, 6, 0, 1], [0, 0, 0, -2, -5, 4, 3, 0, -6, 0, 0, 0, 0, 0, 2, -4, 0, 7, 0, -1], [0, 0, 0, -1, -5, -9, 0, 0, -6, 0, 0, 0, 0, 0, -1, -1, 0, 3, 0, 7], [-10, -5, 0, 0, 0, 0, 0, -15, 0, 11, 11, -4, -2, 4, 0, 0, 5, 0, -6, 0], [16, -4, 0, 0, 0, 0, 0, 4, 0, -1, -16, 5, -1, 3, 0, 0, -1, 0, 1, 0], [1, 2, 0, 0, 0, 0, 0, -2, 0, 1, -4, -2, -7, 7, 0, 0, -1, 0, 0, 0], [0, 0, -3, -3, 1, 4, 1, 0, 8, 0, 0, 0, 0, 0, 0, -6, 0, -1, 0, 2], [21, -13, 0, 0, 0, 0, 0, 2, 0, 13, 4, -1, -1, -1, 0, 0, 3, 0, -1, 0], [9, -20, 0, 0, 0, 0, 0, 1, 0, 14, -6, 0, 3, -1, 0, 0, -1, 0, 1, 0], [22, -9, 0, 0, 0, 0, 0, 3, 0, -5, -5, 2, 4, -2, 0, 0, -3, 0, 2, 0], [12, -6, 0, 0, 0, 0, 0, -1, 0, -11, -1, 3, -5, 1, 0, 0, -5, 0, 5, 0], [0, 0, -1, 1, 6, -7, 1, 0, 0, 0, 0, 0, 0, 0, -4, 8, 0, -4, 0, -1], [0, 0, -10, 0, 4, -2, 5, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, -4], [0, 0, -10, 9, 5, -3, -1, 0, 5, 0, 0, 0, 0, 0, -9, -3, 0, -2, 0, 7], [0, 0, 6, 4, 4, -1, 1, 0, 9, 0, 0, 0, 0, 0, -5, 4, 0, -2, 0, 0], [7, 17, 0, 0, 0, 0, 0, -4, 0, -7, 5, 0, -3, 1, 0, 0, 2, 0, -1, 0], [-8, 10, 0, 0, 0, 0, 0, -4, 0, 2, 7, -4, 10, 0, 0, 0, 0, 0, 4, 0], [11, 13, 0, 0, 0, 0, 0, 1, 0, -1, -9, 7, -1, -7, 0, 0, -9, 0, 5, 0], [0, 0, -1, 5, -2, 2, 1, 0, 7, 0, 0, 0, 0, 0, -5, 2, 0, 2, 0, 3], [-7, 18, 0, 0, 0, 0, 0, -8, 0, -8, 8, -8, 4, 7, 0, 0, 5, 0, -6, 0], [0, 0, 7, -1, -4, 0, -4, 0, -10, 0, 0, 0, 0, 0, -1, -4, 0, -2, 0, 5], [2, -17, 0, 0, 0, 0, 0, -2, 0, -6, 4, 1, -2, 3, 0, 0, -5, 0, -1, 0], [0, 0, -1, -4, 6, 6, 0, 0, -1, 0, 0, 0, 0, 0, -2, -6, 0, 0, 0, -2], [7, -5, 0, 0, 0, 0, 0, -6, 0, -3, 7, -2, 1, 1, 0, 0, 8, 0, -3, 0], [-9, -8, 0, 0, 0, 0, 0, -9, 0, 6, 13, -3, 2, 1, 0, 0, 9, 0, -7, 0], [0, 0, 2, 10, 4, -6, -2, 0, -2, 0, 0, 0, 0, 0, -7, 4, 0, -2, 0, 6], [6, -13, 0, 0, 0, 0, 0, 3, 0, 2, 2, 6, 4, -4, 0, 0, -3, 0, 2, 0], [0, 0, 5, 2, -5, -3, -10, 0, -8, 0, 0, 0, 0, 0, 2, 0, 0, -4, 0, 6], [0, 0, 4, -1, -4, 4, -8, 0, 1, 0, 0, 0, 0, 0, 1, -1, 0, -5, 0, 7], [4, 1, 0, 0, 0, 0, 0, 1, 0, -8, -13, 4, 0, -6, 0, 0, 5, 0, 0, 0], [0, 0, 1, -1, -1, 3, 0, 0, -8, 0, 0, 0, 0, 0, 6, -4, 0, -1, 0, 0], [0, 0, 8, 2, -17, 3, -5, 0, -6, 0, 0, 0, 0, 0, 6, -4, 0, -5, 0, 5], [8, 19, 0, 0, 0, 0, 0, -5, 0, -3, -3, 2, 3, -1, 0, 0, 5, 0, 2, 0], [0, 0, -3, 11, 2, -8, 7, 0, 6, 0, 0, 0, 0, 0, -5, 4, 0, -2, 0, 1], [13, 3, 0, 0, 0, 0, 0, 2, 0, -17, -7, 6, -7, 5, 0, 0, -4, 0, -1, 0], [6, -1, 0, 0, 0, 0, 0, -2, 0, 2, -2, -4, -2, 8, 0, 0, 8, 0, -8, 0], [-20, 9, 0, 0, 0, 0, 0, 7, 0, 2, -2, 2, -6, -4, 0, 0, -5, 0, 6, 0], [0, 0, 2, -2, 4, 0, 4, 0, 4, 0, 0, 0, 0, 0, 5, 4, 0, -4, 0, -4], [26, -5, 0, 0, 0, 0, 0, 5, 0, 5, -5, 4, -3, -4, 0, 0, -6, 0, 6, 0], [-11, 8, 0, 0, 0, 0, 0, -6, 0, -11, -12, -1, 1, -3, 0, 0, 1, 0, -7, 0], [0, 0, -2, 2, 3, 6, -2, 0, 1, 0, 0, 0, 0, 0, -6, 2, 0, 1, 0, -1], [-12, 19, 0, 0, 0, 0, 0, -3, 0, -8, -6, -2, 2, -6, 0, 0, 5, 0, -2, 0], [12, -9, 0, 0, 0, 0, 0, -1, 0, -4, -1, 2, -4, 6, 0, 0, -3, 0, -4, 0], [0, 0, 1, 1, -2, -3, -1, 0, 4, 0, 0, 0, 0, 0, -4, -2, 0, -2, 0, 9], [0, 0, 10, 0, 1, -8, -1, 0, 2, 0, 0, 0, 0, 0, -3, 6, 0, -11, 0, 7], [0, 0, -2, 9, -7, 1, 4, 0, 4, 0, 0, 0, 0, 0, -1, 3, 0, -1, 0, -1], [0, 0, 0, 2, 1, 7, 6, 0, 7, 0, 0, 0, 0, 0, 2, 2, 0, -2, 0, 0], [-5, -11, 0, 0, 0, 0, 0, 2, 0, -4, 6, 0, 3, -1, 0, 0, 2, 0, -7, 0], [0, 0, -10, 2, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, -8, -4, 0, 0, 0, 4], [0, 0, 2, -4, -3, 10, 0, 0, 6, 0, 0, 0, 0, 0, 0, -4, 0, 7, 0, -7], [0, 0, -4, 4, 0, -6, 3, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -2], [0, 0, 2, -2, -1, 2, 1, 0, 2, 0, 0, 0, 0, 0, 4, -2, 0, 1, 0, -3], [20, -1, 0, 0, 0, 0, 0, -1, 0, -5, 9, -2, 9, -2, 0, 0, 2, 0, 8, 0], [-5, 18, 0, 0, 0, 0, 0, 1, 0, -4, 5, 5, 10, -8, 0, 0, 4, 0, -1, 0], [0, 0, -1, 3, -7, 5, -7, 0, -1, 0, 0, 0, 0, 0, -1, -4, 0, -1, 0, 6], [-4, 2, 0, 0, 0, 0, 0, 0, 0, -9, -4, 4, -3, -5, 0, 0, 1, 0, -2, 0], [-4, 12, 0, 0, 0, 0, 0, 9, 0, 2, -5, 3, -2, 1, 0, 0, 3, 0, -3, 0], [0, 0, -1, -5, -6, 5, -7, 0, -1, 0, 0, 0, 0, 0, -3, -2, 0, -2, 0, -3], [0, 0, 3, -12, 0, -2, -6, 0, -9, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -4], [17, -6, 0, 0, 0, 0, 0, 3, 0, -3, -5, 4, -9, -1, 0, 0, -1, 0, 3, 0], [-8, 2, 0, 0, 0, 0, 0, -4, 0, 4, -6, -7, 4, 2, 0, 0, 6, 0, 1, 0], [0, 0, -2, -4, 6, -2, -2, 0, -2, 0, 0, 0, 0, 0, 2, 8, 0, 0, 0, -8], [0, 0, 1, 1, -11, 1, -7, 0, -5, 0, 0, 0, 0, 0, 7, -2, 0, -5, 0, 0], [-5, -10, 0, 0, 0, 0, 0, -7, 0, 13, 3, -2, 9, 7, 0, 0, 3, 0, -3, 0], [0, 0, -4, 5, 6, -10, 3, 0, 2, 0, 0, 0, 0, 0, -7, 11, 0, 0, 0, -5], [4, -17, 0, 0, 0, 0, 0, 4, 0, 15, 14, 4, 5, 0, 0, 0, -2, 0, 2, 0], [0, 0, 3, 6, 0, 8, -1, 0, 4, 0, 0, 0, 0, 0, 0, 2, 0, -5, 0, 2], [0, 0, 3, -1, 10, -9, 7, 0, 4, 0, 0, 0, 0, 0, -4, 10, 0, -4, 0, -7], [0, 0, 3, -2, 2, -8, 3, 0, -2, 0, 0, 0, 0, 0, 4, 4, 0, -3, 0, -4], [13, -4, 0, 0, 0, 0, 0, 7, 0, 4, -13, -2, 4, 2, 0, 0, 0, 0, 0, 0], [-35, -9, 0, 0, 0, 0, 0, -6, 0, 9, 5, -8, 5, 7, 0, 0, 4, 0, 5, 0], [-17, 13, 0, 0, 0, 0, 0, -2, 0, -2, 16, -6, -2, 1, 0, 0, 9, 0, -4, 0], [0, 0, 15, -5, -6, -10, -7, 0, -5, 0, 0, 0, 0, 0, 5, 3, 0, -8, 0, -1], [-25, -6, 0, 0, 0, 0, 0, -3, 0, 1, 5, -6, -3, 5, 0, 0, 1, 0, -5, 0], [0, 0, -3, 0, 4, 0, 4, 0, 3, 0, 0, 0, 0, 0, 4, 0, 0, -6, 0, 0], [-9, 17, 0, 0, 0, 0, 0, -8, 0, 2, 1, -8, 1, 1, 0, 0, 6, 0, -1, 0], [0, 0, 6, 11, 2, -6, -6, 0, -1, 0, 0, 0, 0, 0, -9, 5, 0, -3, 0, 7], [0, 0, -5, 3, -2, 4, -4, 0, -2, 0, 0, 0, 0, 0, -4, -6, 0, 10, 0, 1], [-12, 12, 0, 0, 0, 0, 0, -2, 0, 5, 12, 0, -2, 2, 0, 0, 4, 0, -2, 0], [0, 0, 3, -4, -9, 9, -10, 0, -4, 0, 0, 0, 0, 0, 2, -4, 0, 6, 0, -8], [9, 0, 0, 0, 0, 0, 0, 0, 0, 9, -2, 4, 5, 3, 0, 0, -1, 0, -8, 0], [0, 0, -1, -5, 2, -6, 1, 0, -5, 0, 0, 0, 0, 0, -3, -2, 0, -2, 0, -3], [0, 0, 6, 0, -1, 3, -1, 0, 5, 0, 0, 0, 0, 0, -6, 6, 0, -7, 0, -1], [21, 2, 0, 0, 0, 0, 0, 3, 0, 4, -6, 4, 3, -1, 0, 0, 1, 0, 5, 0], [0, 0, 6, -2, 3, -6, 3, 0, 4, 0, 0, 0, 0, 0, 4, 4, 0, -9, 0, 3], [0, 0, 7, 4, -11, 3, -3, 0, -1, 0, 0, 0, 0, 0, -2, 4, 0, -1, 0, 4], [14, 11, 0, 0, 0, 0, 0, 1, 0, -6, 5, 4, 6, 4, 0, 0, -1, 0, 0, 0], [3, 29, 0, 0, 0, 0, 0, 0, 0, -1, -4, 0, 1, 1, 0, 0, 6, 0, -5, 0], [0, 0, 7, -5, -7, -1, -6, 0, -9, 0, 0, 0, 0, 0, 9, 7, 0, -7, 0, 1], [9, 8, 0, 0, 0, 0, 0, 1, 0, -10, 1, 0, 6, 4, 0, 0, 8, 0, -2, 0], [-12, 20, 0, 0, 0, 0, 0, -6, 0, 7, 13, -4, -2, -2, 0, 0, 4, 0, 2, 0], [-8, 1, 0, 0, 0, 0, 0, -11, 0, 3, 11, -2, 3, 14, 0, 0, 6, 0, -6, 0], [0, 0, 5, -9, 5, -5, 0, 0, -5, 0, 0, 0, 0, 0, 5, -3, 0, -5, 0, -5], [-6, -7, 0, 0, 0, 0, 0, -5, 0, -2, -6, -4, 2, 6, 0, 0, 1, 0, -12, 0], [0, 0, 8, 1, -2, 4, -7, 0, 4, 0, 0, 0, 0, 0, -1, 3, 0, -6, 0, 3], [0, 0, 0, -8, -8, 1, -5, 0, -5, 0, 0, 0, 0, 0, 2, -8, 0, 0, 0, 2], [-4, 5, 0, 0, 0, 0, 0, 16, 0, 0, -22, 5, -6, -7, 0, 0, -5, 0, 3, 0], [0, 0, -9, -1, 7, -1, -4, 0, -5, 0, 0, 0, 0, 0, -5, -7, 0, 3, 0, -5], [-20, 8, 0, 0, 0, 0, 0, 0, 0, 0, -1, -4, 8, -4, 0, 0, 0, 0, 8, 0], [9, -22, 0, 0, 0, 0, 0, 11, 0, 2, -13, 6, -4, -7, 0, 0, -1, 0, 2, 0], [0, 0, -5, -3, -7, -5, -4, 0, -2, 0, 0, 0, 0, 0, 0, -12, 0, 1, 0, 4], [-10, 5, 0, 0, 0, 0, 0, 5, 0, 0, -4, 10, 0, 0, 0, 0, -1, 0, -2, 0], [0, 0, 2, -6, -2, 2, 1, 0, 1, 0, 0, 0, 0, 0, 4, 0, 0, -3, 0, 6], [-36, 22, 0, 0, 0, 0, 0, -6, 0, -7, 16, -3, 3, -5, 0, 0, 5, 0, 5, 0], [-25, 30, 0, 0, 0, 0, 0, -7, 0, -11, 5, -6, 1, -5, 0, 0, 3, 0, -3, 0]]
